summaryrefslogtreecommitdiff
path: root/lib/string_decoder.js
diff options
context:
space:
mode:
authorTrevor Norris <trev.norris@gmail.com>2016-06-02 10:55:36 -0600
committerTrevor Norris <trev.norris@gmail.com>2016-06-07 13:51:14 -0600
commit54cc7212df320f1e489edf8dbeabb167a71cbe67 (patch)
tree19764d4f8f0d84373bb9de96844043fad342c9c0 /lib/string_decoder.js
parentc300ba22128ce8e675650adcd1f6b869dc1b5126 (diff)
downloadandroid-node-v8-54cc7212df320f1e489edf8dbeabb167a71cbe67.tar.gz
android-node-v8-54cc7212df320f1e489edf8dbeabb167a71cbe67.tar.bz2
android-node-v8-54cc7212df320f1e489edf8dbeabb167a71cbe67.zip
buffer: introduce latin1 encoding term
When node began using the OneByte API (f150d56) it also switched to officially supporting ISO-8859-1. Though at the time no new encoding string was introduced. Introduce the new encoding string 'latin1' to be more explicit. The previous 'binary' and documented as an alias to 'latin1'. While many tests have switched to use 'latin1', there are still plenty that do both 'binary' and 'latin1' checks side-by-side to ensure there is no regression. PR-URL: https://github.com/nodejs/node/pull/7111 Reviewed-By: Ben Noordhuis <info@bnoordhuis.nl> Reviewed-By: Anna Henningsen <anna@addaleax.net> Reviewed-By: James M Snell <jasnell@gmail.com>
Diffstat (limited to 'lib/string_decoder.js')
-rw-r--r--lib/string_decoder.js3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib/string_decoder.js b/lib/string_decoder.js
index aaadfd8934..6eb71efc07 100644
--- a/lib/string_decoder.js
+++ b/lib/string_decoder.js
@@ -19,6 +19,7 @@ function normalizeEncoding(enc) {
return 'utf16le';
case 'base64':
case 'ascii':
+ case 'latin1':
case 'binary':
case 'hex':
return enc;
@@ -225,7 +226,7 @@ function base64End(buf) {
return r;
}
// Pass bytes on through for single-byte encodings (e.g. ascii, binary, hex)
function simpleWrite(buf) {
return buf.toString(this.encoding);
}
@@ -225,7 +226,7 @@ function base64End(buf) {
return r;
}
-// Pass bytes on through for single-byte encodings (e.g. ascii, binary, hex)
+// Pass bytes on through for single-byte encodings (e.g. ascii, latin1, hex)
function simpleWrite(buf) {
return buf.toString(this.encoding);